@@ -33,7 +33,7 @@ class ForwardTestBase < NetSSHTest
   end
 
   def ssh_start_params(options = {})
-    [localhost,user, { keys: @key_id_rsa }.merge(options)]
+    [localhost, user, { keys: @key_id_rsa }.merge(options)]
   end
 
   def setup_ssh_env(&block)
@@ -41,7 +41,7 @@ class ForwardTestBase < NetSSHTest
       @key_id_rsa = "#{dir}/id_rsa"
       sh "rm -rf #{@key_id_rsa} #{@key_id_rsa}.pub"
       sh "ssh-keygen -q -f #{@key_id_rsa} -t rsa -N ''"
-      set_authorized_key(user,"#{@key_id_rsa}.pub")
+      set_authorized_key(user, "#{@key_id_rsa}.pub")
       yield
     end
   end
@@ -51,15 +51,13 @@ class ForwardTestBase < NetSSHTest
     Thread.start do
       loop do
         Thread.start(server.accept) do |client|
-          begin
-            10000.times do |i|
-              client.puts "item#{i}"
-            end
-            client.close
-          rescue StandardError
-            exceptions << $!
-            raise
+          10000.times do |i|
+            client.puts "item#{i}"
           end
+          client.close
+        rescue StandardError
+          exceptions << $!
+          raise
         end
       end
     end
@@ -68,19 +66,17 @@ class ForwardTestBase < NetSSHTest
 end
 
 class TestForward < ForwardTestBase
-  def start_server_closing_soon(exceptions=nil)
+  def start_server_closing_soon(exceptions = nil)
     server = TCPServer.open(0)
     Thread.start do
       loop do
         Thread.start(server.accept) do |client|
-          begin
-            client.recv(1024)
-            client.setsockopt(Socket::SOL_SOCKET, Socket::SO_LINGER, [1, 0].pack("ii"))
-            client.close
-          rescue StandardError
-            exceptions << $!
-            raise
-          end
+          client.recv(1024)
+          client.setsockopt(Socket::SOL_SOCKET, Socket::SO_LINGER, [1, 0].pack("ii"))
+          client.close
+        rescue StandardError
+          exceptions << $!
+          raise
         end
       end
     end
@@ -187,14 +183,12 @@ class TestForward < ForwardTestBase
       session.forward.local(local_port, localhost, remote_port)
       client_done = Queue.new
       Thread.start do
-        begin
-          client = TCPSocket.new(localhost, local_port)
-          client.recv(1024)
-          client.close
-          sleep(0.2)
-        ensure
-          client_done << true
-        end
+        client = TCPSocket.new(localhost, local_port)
+        client.recv(1024)
+        client.close
+        sleep(0.2)
+      ensure
+        client_done << true
       end
       session.loop(0.1) { client_done.empty? }
       assert_equal "Broken pipe", server_exc.pop.to_s unless server_exc.empty?
@@ -211,15 +205,13 @@ class TestForward < ForwardTestBase
       session.forward.local(local_port, localhost, remote_port)
       client_done = Queue.new
       Thread.start do
-        begin
-          client = TCPSocket.new(localhost, local_port)
-          client.recv(1024)
-          client.setsockopt(Socket::SOL_SOCKET, Socket::SO_LINGER, [1, 0].pack("ii"))
-          client.close
-          sleep(0.1)
-        ensure
-          client_done << true
-        end
+        client = TCPSocket.new(localhost, local_port)
+        client.recv(1024)
+        client.setsockopt(Socket::SOL_SOCKET, Socket::SO_LINGER, [1, 0].pack("ii"))
+        client.close
+        sleep(0.1)
+      ensure
+        client_done << true
       end
       session.loop(0.1) { client_done.empty? }
       assert_equal "Broken pipe", server_exc.pop.to_s unless server_exc.empty?
@@ -235,16 +227,14 @@ class TestForward < ForwardTestBase
       session.forward.local(local_port, localhost, remote_port)
       client_done = Queue.new
       Thread.start do
-        begin
-          client = TCPSocket.new(localhost, local_port)
-          1.times do |i|
-            client.puts "item#{i}"
-          end
-          client.close
-          sleep(0.1)
-        ensure
-          client_done << true
+        client = TCPSocket.new(localhost, local_port)
+        1.times do |i|
+          client.puts "item#{i}"
         end
+        client.close
+        sleep(0.1)
+      ensure
+        client_done << true
       end
       session.loop(0.1) { client_done.empty? }
     end
@@ -268,31 +258,27 @@ class TestForward < ForwardTestBase
       session = Net::SSH.start(*ssh_start_params)
       server_done = Queue.new
       server = start_server do |client|
-        begin
-          data = client.read message.size
-          server_done << data
-          client.close
-        rescue StandardError
-          server_done << $!
-        end
+        data = client.read message.size
+        server_done << data
+        client.close
+      rescue StandardError
+        server_done << $!
       end
       client_done = Queue.new
       got_remote_port = Queue.new
       local_port = server.addr[1]
-      session.forward.remote(0, localhost, local_port, localhost) do |actual_remote_port|
+      session.forward.remote(local_port, localhost, 0, localhost) do |actual_remote_port|
         got_remote_port << actual_remote_port
       end
       session.loop(0.1) { got_remote_port.empty? }
       remote_port = got_remote_port.pop
       Thread.start do
-        begin
-          client = TCPSocket.new(localhost, remote_port)
-          client.write(message)
-          client.close
-          client_done << true
-        rescue StandardError
-          client_done << $!
-        end
+        client = TCPSocket.new(localhost, remote_port)
+        client.write(message)
+        client.close
+        client_done << true
+      rescue StandardError
+        client_done << $!
       end
       Timeout.timeout(5) do
         session.loop(0.1) { server_done.empty? }
@@ -302,13 +288,13 @@ class TestForward < ForwardTestBase
   end
 
   class TCPProxy
-    def initialize()
+    def initialize
       @sockets = []
     end
     attr_reader :sockets
 
     def open(host, port, connection_options = nil)
-      socket = TCPSocket.new(host,port)
+      socket = TCPSocket.new(host, port)
       @sockets << socket
       socket
     end
@@ -333,25 +319,21 @@ class TestForward < ForwardTestBase
       # read on forwarded port
       client_done = Queue.new
       Thread.start do
-        begin
-          client = TCPSocket.new(localhost, local_port)
-          client.read(6)
-          proxy.close_all
-          client.read(7)
-          client.close
-          client_done << true
-        rescue StandardError
-          client_done << $!
-        end
+        client = TCPSocket.new(localhost, local_port)
+        client.read(6)
+        proxy.close_all
+        client.read(7)
+        client.close
+        client_done << true
+      rescue StandardError
+        client_done << $!
       end
       server_error = nil
       Timeout.timeout(5) do
-        begin
-          session.loop(0.1) { true }
-        rescue IOError, Errno::EBADF
-          server_error = $!
-          # puts "Error: #{$!} #{$!.backtrace.join("\n")}"
-        end
+        session.loop(0.1) { true }
+      rescue IOError, Errno::EBADF
+        server_error = $!
+        # puts "Error: #{$!} #{$!.backtrace.join("\n")}"
       end
       begin
         Timeout.timeout(5) do
@@ -379,16 +361,14 @@ class TestForward < ForwardTestBase
       # read on forwarded port
       client_done = Queue.new
       Thread.start do
-        begin
-          client = TCPSocket.new(localhost, local_port)
-          client.read(6)
-          system("killall /bin/nc")
-          client.read(7)
-          client.close
-          client_done << true
-        rescue StandardError
-          client_done << $!
-        end
+        client = TCPSocket.new(localhost, local_port)
+        client.read(6)
+        system("killall /bin/nc")
+        client.read(7)
+        client.close
+        client_done << true
+      rescue StandardError
+        client_done << $!
       end
       Timeout.timeout(5) do
         begin
@@ -411,26 +391,22 @@ class TestForward < ForwardTestBase
       session = Net::SSH.start(*ssh_start_params)
       server_done = Queue.new
       server = start_server do |client|
-        begin
-          data = client.read message.size
-          server_done << data
-          client.close
-        rescue StandardError
-          server_done << $!
-        end
+        data = client.read message.size
+        server_done << data
+        client.close
+      rescue StandardError
+        server_done << $!
       end
       client_done = Queue.new
       remote_port = server.addr[1]
       local_port = session.forward.local(0, localhost, remote_port)
       Thread.start do
-        begin
-          client = TCPSocket.new(localhost, local_port)
-          client.write(message)
-          client.close
-          client_done << true
-        rescue StandardError
-          client_done << $!
-        end
+        client = TCPSocket.new(localhost, local_port)
+        client.write(message)
+        client.close
+        client_done << true
+      rescue StandardError
+        client_done << $!
       end
       Timeout.timeout(5) do
         session.loop(0.1) { server_done.empty? }
@@ -442,7 +418,7 @@ class TestForward < ForwardTestBase
   def test_server_eof_should_be_handled_remote
     setup_ssh_env do
       message = "This is a small message!"
-      session = Net::SSH.start(*ssh_start_params)
+      session = Net::SSH.start(*ssh_start_params(verbose: :debug))
       server = start_server do |client|
         client.write message
         client.close
@@ -450,20 +426,21 @@ class TestForward < ForwardTestBase
       client_done = Queue.new
       got_remote_port = Queue.new
       local_port = server.addr[1]
-      session.forward.remote(0, localhost, local_port, localhost) do |actual_remote_port|
+      puts "LOCAL PORT: #{local_port}"
+      session.forward.remote(local_port, localhost, 0, localhost) do |actual_remote_port|
         got_remote_port << actual_remote_port
       end
       session.loop(0.1) { got_remote_port.empty? }
       remote_port = got_remote_port.pop
+      puts "Remote port:#{remote_port}"
       Thread.start do
-        begin
-          client = TCPSocket.new(localhost, remote_port)
-          data = client.read(4096)
-          client.close
-          client_done << data
-        rescue StandardError
-          client_done << $!
-        end
+        client = TCPSocket.new(localhost, remote_port)
+        data = client.read(4096)
+        client.close
+        client_done << data
+        puts "Received: #{data}"
+      rescue StandardError
+        client_done << $!
       end
       Timeout.timeout(5) do
         session.loop(0.1) { client_done.empty? }
@@ -484,14 +461,12 @@ class TestForward < ForwardTestBase
       remote_port = server.addr[1]
       local_port = session.forward.local(0, localhost, remote_port)
       Thread.start do
-        begin
-          client = TCPSocket.new(localhost, local_port)
-          data = client.read(4096)
-          client.close
-          client_done << data
-        rescue StandardError
-          client_done << $!
-        end
+        client = TCPSocket.new(localhost, local_port)
+        data = client.read(4096)
+        client.close
+        client_done << data
+      rescue StandardError
+        client_done << $!
       end
       Timeout.timeout(5) do
         session.loop(0.1) { client_done.empty? }
@@ -502,14 +477,12 @@ class TestForward < ForwardTestBase
 
   def _run_reading_client(client_done, local_port)
     Thread.start do
-      begin
-        client = TCPSocket.new(localhost, local_port)
-        data = client.read(4096)
-        client.close
-        client_done << data
-      rescue StandardError
-        client_done << $!
-      end
+      client = TCPSocket.new(localhost, local_port)
+      data = client.read(4096)
+      client.close
+      client_done << data
+    rescue StandardError
+      client_done << $!
     end
   end
 
@@ -621,14 +594,12 @@ class TestForwardOnUnixSockets < ForwardTestBase
           client_done = Queue.new
 
           Thread.start do
-            begin
-              client = UNIXSocket.new(local_socket.path)
-              client_data = client.recv(1024)
-              client.close
-              sleep(0.2)
-            ensure
-              client_done << true
-            end
+            client = UNIXSocket.new(local_socket.path)
+            client_data = client.recv(1024)
+            client.close
+            sleep(0.2)
+          ensure
+            client_done << true
           end
 
           begin
@@ -646,16 +617,15 @@ class TestForwardOnUnixSockets < ForwardTestBase
   def test_forward_local_unix_socket_to_remote_socket
     setup_ssh_env do
       start_sshd_7_or_later do |_pid, port|
-        session = Timeout.timeout(4) do
-          begin
-            # We have our own sshd, give it a chance to come up before
-            # listening.
+        session =
+          # We have our own sshd, give it a chance to come up before
+          # listening.
+          Timeout.timeout(4) do
             Net::SSH.start(*ssh_start_params(port: port))
           rescue SocketError, Errno::ECONNREFUSED, Errno::EHOSTUNREACH
             sleep 0.25
             retry
           end
-        end
 
         create_local_socket do |remote_socket|
           # Make sure sshd can 'rw'.
