@@ -3,6 +3,7 @@ require 'net/ssh/buffer'
 require 'net/ssh'
 require 'timeout'
 require 'tempfile'
+require 'fileutils'
 require 'net/ssh/proxy/command'
 require 'net/ssh/proxy/jump'
 
@@ -18,7 +19,7 @@ class TestProxy < NetSSHTest
   end
 
   def ssh_start_params(options)
-    [localhost,user, { keys: @key_id_rsa }.merge(options)]
+    [localhost, user, { keys: @key_id_rsa }.merge(options)]
   end
 
   def setup_ssh_env(&block)
@@ -26,7 +27,7 @@ class TestProxy < NetSSHTest
       @key_id_rsa = "#{dir}/id_rsa"
       sh "rm -rf #{@key_id_rsa} #{@key_id_rsa}.pub"
       sh "ssh-keygen -q -f #{@key_id_rsa} -t rsa -N ''"
-      set_authorized_key(user,"#{@key_id_rsa}.pub")
+      set_authorized_key(user, "#{@key_id_rsa}.pub")
       yield
     end
   end
@@ -38,11 +39,12 @@ class TestProxy < NetSSHTest
       @gwkey_id_rsa = "#{dir}/id_rsa"
       sh "rm -rf #{@gwkey_id_rsa} #{@gwkey_id_rsa}.pub"
       sh "ssh-keygen -q -f #{@gwkey_id_rsa} -t rsa -N ''"
-      set_authorized_key(gwuser,"#{@gwkey_id_rsa}.pub")
+      set_authorized_key(gwuser, "#{@gwkey_id_rsa}.pub")
       config = "Host #{gwhost}
                   IdentityFile #{@gwkey_id_rsa}
                   StrictHostKeyChecking no
                "
+      FileUtils.mkdir_p File.expand_path("~/.ssh")
       my_config = File.expand_path("~/.ssh/config")
       File.open(my_config, 'w') { |file| file.write(config) }
       begin
@@ -65,7 +67,7 @@ class TestProxy < NetSSHTest
     end
   end
 
-  def with_spurious_write_wakeup_emulate(rate=99,&block)
+  def with_spurious_write_wakeup_emulate(rate = 99, &block)
     orig_io_select = IO.method(:select)
     count = 0
 
@@ -73,7 +75,7 @@ class TestProxy < NetSSHTest
       count += 1
       if (count % rate != 0)
         if params && params[1] && !params[1].empty?
-          return [[],params[1],[]]
+          return [[], params[1], []]
         end
       end
       orig_io_select.call(*params)
@@ -97,7 +99,7 @@ class TestProxy < NetSSHTest
         ok = Net::SSH.start(*ssh_start_params(proxy: proxy)) do |ssh|
           with_spurious_write_wakeup_emulate do
             ret = ssh.exec! "echo \"$USER:#{large_msg}\""
-            assert_equal "/bin/sh: Argument list too long\n", ret
+            assert_match(%r{/bin/.*sh: Argument list too long\n}, ret)
             hello_count = 1000
             ret = ssh.exec! "ruby -e 'puts \"Hello\"*#{hello_count}'"
             assert_equal "Hello" * hello_count + "\n", ret
@@ -137,6 +139,7 @@ class TestProxy < NetSSHTest
       @io
     end
   end
+
   def test_does_close_proxy_on_proxy_failure
     setup_ssh_env do
       proxy = DbgProxy.new(Net::SSH::Proxy::Command.new('sleep 2 && ssh -W %h:%p -o "PreferredAuthentications none" user@localhost'))
