@@ -122,29 +122,29 @@ class TestConfig < NetSSHTest
 
   def test_translate_should_correctly_translate_from_openssh_to_net_ssh_names
     open_ssh = {
-      'bindaddress'             => "127.0.0.1",
-      'ciphers'                 => "a,b,c",
-      'compression'             => true,
-      'compressionlevel'        => 6,
-      'connecttimeout'          => 100,
-      'forwardagent'            => true,
+      'bindaddress' => "127.0.0.1",
+      'ciphers' => "a,b,c",
+      'compression' => true,
+      'compressionlevel' => 6,
+      'connecttimeout' => 100,
+      'forwardagent' => true,
       'hostbasedauthentication' => true,
-      'hostkeyalgorithms'       => "d,e,f",
-      'identityfile'            => %w(g h i),
-      'macs'                    => "j,k,l",
-      'certificatefile'         => %w(m n o),
-      'passwordauthentication'  => true,
-      'port'                    => 1234,
-      'pubkeyauthentication'    => true,
-      'rekeylimit'              => 1024,
-      'sendenv'                 => "LC_*",
-      'setenv'                  => 'foo="bar" baz=whale cat="black hole"',
+      'hostkeyalgorithms' => "d,e,f",
+      'identityfile' => %w(g h i),
+      'macs' => "j,k,l",
+      'certificatefile' => %w(m n o),
+      'passwordauthentication' => true,
+      'port' => 1234,
+      'pubkeyauthentication' => true,
+      'rekeylimit' => 1024,
+      'sendenv' => "LC_*",
+      'setenv' => 'foo="bar" baz=whale cat="black hole"',
       'numberofpasswordprompts' => '123',
-      'serveraliveinterval'     => '2',
-      'serveralivecountmax'     => '4',
-      'fingerprinthash'         => 'MD5',
-      'userknownhostsfile'      => '/dev/null',
-      'stricthostkeychecking'   => false
+      'serveraliveinterval' => '2',
+      'serveralivecountmax' => '4',
+      'fingerprinthash' => 'MD5',
+      'userknownhostsfile' => '/dev/null',
+      'stricthostkeychecking' => false
     }
 
     net_ssh = Net::SSH::Config.translate(open_ssh)
@@ -170,16 +170,32 @@ class TestConfig < NetSSHTest
     assert_equal 'MD5',     net_ssh[:fingerprint_hash]
     assert_equal true,      net_ssh[:keepalive]
     assert_equal '/dev/null', net_ssh[:user_known_hosts_file]
-    assert_equal false, net_ssh[:strict_host_key_checking]
+    assert_equal :never, net_ssh[:verify_host_key]
+  end
+
+  def test_translate_should_turn_on_host_key_verification
+    open_ssh = { 'stricthostkeychecking' => true }
+
+    net_ssh = Net::SSH::Config.translate(open_ssh)
+
+    assert_equal :always, net_ssh[:verify_host_key]
+  end
+
+  def test_translate_should_accept_new_host_key
+    open_ssh = { 'stricthostkeychecking' => 'accept-new' }
+
+    net_ssh = Net::SSH::Config.translate(open_ssh)
+
+    assert_equal :accept_new, net_ssh[:verify_host_key]
   end
 
   def test_translate_should_turn_off_authentication_methods
     open_ssh = {
-      'hostbasedauthentication'         => false,
-      'passwordauthentication'          => false,
-      'pubkeyauthentication'            => false,
+      'hostbasedauthentication' => false,
+      'passwordauthentication' => false,
+      'pubkeyauthentication' => false,
       'challengeresponseauthentication' => false,
-      'kbdinteractiveauthentication'    => false
+      'kbdinteractiveauthentication' => false
     }
 
     net_ssh = Net::SSH::Config.translate(open_ssh)
@@ -189,11 +205,11 @@ class TestConfig < NetSSHTest
 
   def test_translate_should_turn_on_authentication_methods
     open_ssh = {
-      'hostbasedauthentication'         => true,
-      'passwordauthentication'          => true,
-      'pubkeyauthentication'            => true,
+      'hostbasedauthentication' => true,
+      'passwordauthentication' => true,
+      'pubkeyauthentication' => true,
       'challengeresponseauthentication' => true,
-      'kbdinteractiveauthentication'    => true
+      'kbdinteractiveauthentication' => true
     }
 
     net_ssh = Net::SSH::Config.translate(open_ssh)
@@ -202,9 +218,7 @@ class TestConfig < NetSSHTest
   end
 
   def test_translate_should_not_disable_keyboard_interactive_when_challange_or_keyboardinterective_is_on
-    open_ssh = {
-      'kbdinteractiveauthentication' => false
-    }
+    open_ssh = { 'kbdinteractiveauthentication' => false }
     net_ssh = Net::SSH::Config.translate(open_ssh)
     assert_equal %w(keyboard-interactive none password publickey), net_ssh[:auth_methods].sort
 
@@ -529,7 +543,7 @@ class TestConfig < NetSSHTest
 
   private
 
-  def with_home_env(value,&block)
+  def with_home_env(value, &block)
     env_home_before = ENV['HOME']
     begin
       ENV['HOME'] = value
